@@ -43,7 +43,9 @@ parser.add_argument('--noprogress',  action="store_true",  help='Disable progres
 
 def evaluate_report_student(report, question=None, qitem=None, unmute=None, passall=None, ignore_missing_file=False,
                             show_tol_err=False, show_privisional=True, noprogress=None,
-                            generate_artifacts=True):
+                            generate_artifacts=True,
+                            show_errors_in_grade_mode=True # This is included for debugging purpose. Should always be True.
+                            ):
     args = parser.parse_args()
     if noprogress is None:
         noprogress = args.noprogress
@@ -66,7 +68,7 @@ def evaluate_report_student(report, question=None, qitem=None, unmute=None, pass
     results, table_data = evaluate_report(report, question=question, show_progress_bar=not unmute and not noprogress, qitem=qitem,
                                           verbose=False, passall=passall, show_expected=args.showexpected, show_computed=args.showcomputed,unmute=unmute,
                                           show_tol_err=show_tol_err,
-                                          generate_artifacts=generate_artifacts)
+                                          generate_artifacts=generate_artifacts, show_errors_in_grade_mode=show_errors_in_grade_mode)
 
 
     if question is None and show_privisional:
@@ -109,7 +111,9 @@ def evaluate_report(report, question=None, qitem=None, passall=False, verbose=Fa
                     show_progress_bar=True,
                     show_tol_err=False,
                     generate_artifacts=True, # Generate the artifact .json files. These are exclusively used by the dashboard.
-                    big_header=True):
+                    big_header=True,
+                    show_errors_in_grade_mode=True # Show test error during grading.
+                    ):
 
     from unitgrade.version import __version__
     now = datetime.now()
@@ -152,6 +156,7 @@ def evaluate_report(report, question=None, qitem=None, passall=False, verbose=Fa
         UTextResult.number = n
         UTextResult.nL = report.nL
         UTextResult.unmute = unmute # Hacky as well.
+        UTextResult.show_errors_in_grade_mode = show_errors_in_grade_mode
         UTextResult.setUpClass_time = q._cache.get(((q.__name__, 'setUpClass'), 'time'), 3) if hasattr(q, '_cache') and q._cache is not None else 3
 
 
