@@ -120,6 +120,9 @@ class Report:
         relative_path = os.path.relpath(self._file(), root_dir)
         modules = os.path.normpath(relative_path[:-3]).split(os.sep)
         relative_path = relative_path.replace("\\", "/")
+        if relative_path.startswith(".."):
+            raise Exception("Bad relative path. setup failed. ", root_dir, self._file())
+
         return root_dir, relative_path, modules
 
     def __init__(self, strict=False, payload=None):
@@ -351,6 +354,16 @@ class UTestCase(unittest.TestCase):
         # print("Run called in test framework...", self._generate_artifacts)
         if not self._generate_artifacts:
             return super().run(result)
+
+        print(result)
+        mute = False
+        if isinstance(result, UTextResult):
+            print(result.show_errors_in_grade_mode)
+            mute = not result.show_errors_in_grade_mode
+        else:
+            pass
+            # print("this' not a text result.")
+        # print(result.show_errors_in_grade_mode)
         from unitgrade.artifacts import StdCapturing
         from unitgrade.utils import DKPupDB
         self._error_fed_during_run = [] # Initialize this to be empty.
@@ -362,8 +375,8 @@ class UTestCase(unittest.TestCase):
 
         _stdout = sys.stdout
         _stderr = sys.stderr
-
-        std_capture = StdCapturing(stdout=sys.stdout, stderr=sys.stderr, db=db, mute=False)
+        # mute = True
+        std_capture = StdCapturing(stdout=sys.stdout, stderr=sys.stderr, db=db, mute=mute)
 
         state_ = None
         try:
@@ -376,17 +389,13 @@ class UTestCase(unittest.TestCase):
             # db.get('stdout')
             # db.get('stderr')
             # db.get("history")
-
-
             result_ = TestCase.run(self, result)
             from werkzeug.debug.tbtools import DebugTraceback, _process_traceback
 
-
             # What could be nice to upload?
             # When the files are edited?
             # When tests are run?
             # how to register it? (report, question, user...)
-            #
             # print(result_._excinfo[0])
             actual_errors = []
             for test, err in self._error_fed_during_run:
@@ -467,7 +476,7 @@ class UTestCase(unittest.TestCase):
                     for ll in data.contexts_by_lineno(file):
 
                         l = ll-1
-                        print(l, lines2[l])
+                        # print(l, lines2[l])
                         if l < len(lines2) and lines2[l].strip() == garb:
                             print("Got one.")
                             rel = os.path.relpath(child, root)
@@ -531,6 +540,8 @@ class UTestCase(unittest.TestCase):
 
     def __init__(self, *args, skip_remote_check=False, **kwargs):
         super().__init__(*args, **kwargs)
+        # print(f"INIT CALED IN {self}")
+
         self._load_cache()
         self._assert_cache_index = 0
         # Perhaps do a sanity check here to see if the cache is up to date? To do that, we must make sure the
@@ -856,8 +867,19 @@ class NotebookTestCase(UTestCase):
     _nb = None
     @classmethod
     def setUpClass(cls) -> None:
+        f = cls._cache_file()
+        # print(f)
+        file = os.path.dirname(os.path.dirname(f)) + "/" + cls.notebook
+        # print(f"{f=}, {file=}, {cls.notebook=}")
+        # print(__file__)
+        print(os.path.curdir)
+        # print("cwd", os.getcwd())
         with Capturing():
-            cls._nb = importnb.Notebook.load(cls.notebook)
+            # print(__file__)
+            f = cls._cache_file()
+            # print(f)
+            file = os.path.dirname(os.path.dirname(f)) + "/" + cls.notebook
+            cls._nb = importnb.Notebook.load_argv(file + " -nograde")
 
     @property
     def nb(self):
