@@ -137,7 +137,7 @@ class ActiveProgress():
 
     def terminate(self):
         if not self._running:
-            print("Stopping a progress bar which is not running (class unitgrade.utils.ActiveProgress")
+            # print("Stopping a progress bar which is not running (class unitgrade.utils.ActiveProgress")
             pass
             # raise Exception("Stopping a stopped progress bar. ")
         self._running = False
@@ -152,10 +152,7 @@ class ActiveProgress():
 
         if self.mute_stdout:
             import io
-            # from unitgrade.utils import Logger
-            sys.stdout = self._stdout #= sys.stdout
-
-            # sys.stdout = Logger(io.StringIO(), write_to_stdout=False)
+            sys.stdout = self._stdout
 
         return time.time() - self.time_started
 
@@ -308,20 +305,28 @@ def load_token(file_in):
 
 ## Key/value store related.
 class DKPupDB:
+    DISABLE_DB = False
     """ This key/value store store artifacts (associated with a specific question) in a dictionary. """
     def __init__(self, artifact_file, use_pupdb=False, register_ephemeral=False):
         # Make a double-headed disk cache thingy.
-        self.dk = Cache(os.path.dirname(artifact_file)) # Start in this directory.
-        self.name_ = os.path.basename(artifact_file[:-5])
-        if self.name_ not in self.dk:
-            self.dk[self.name_] = dict()
-        self.use_pupdb = use_pupdb
-        self.register_ephemeral = register_ephemeral
-        if self.use_pupdb:
-            from pupdb.core import PupDB
-            self.db_ = PupDB(artifact_file)
+        try:
+            self.dk = Cache(os.path.dirname(artifact_file)) # Start in this directory.
+            self.name_ = os.path.basename(artifact_file[:-5])
+            if self.name_ not in self.dk:
+                self.dk[self.name_] = dict()
+            self.use_pupdb = use_pupdb
+            self.register_ephemeral = register_ephemeral
+            if self.use_pupdb:
+                from pupdb.core import PupDB
+                self.db_ = PupDB(artifact_file)
+        except Exception as e:
+            # print("Artifact file not readable. Possibly ")
+            self.DISABLE_DB = True
+            pass
 
     def __setitem__(self, key, value):
+        if self.DISABLE_DB:
+            return
         if self.use_pupdb:
             self.db_.set(key, value)
         with self.dk.transact():
@@ -332,6 +337,8 @@ class DKPupDB:
             self.dk[self.name_ + "-updated"] = True
 
     def __getitem__(self, item):
+        if self.DISABLE_DB:
+            return "db disabled due to bad artifact file."
         v = self.dk[self.name_][item]
         if self.use_pupdb:
             v2 = self.db_.get(item)
@@ -344,11 +351,17 @@ class DKPupDB:
         # return self.db_.keys()
 
     def set(self, item, value): # This one is deprecated.
+        if self.DISABLE_DB:
+            return
         self[item] = value
 
     def get(self, item, default=None):
+        if self.DISABLE_DB:
+            return "artifact file not loaded."
         return self[item] if item in self else default
 
     def __contains__(self, item):
+        if self.DISABLE_DB:
+            return False
         return item in self.dk[self.name_] #keys()
         # return item in self.dk
